# delimit ;
clear;
clear mata;
clear matrix;
set more off ;
capture log close;
set maxvar 32767, permanently;
set matsize 11000, permanently;
pause on;


** --------------------------------------------------------------------------- ;
** Set file paths ;
** --------------------------------------------------------------------------- ;

local rawdir "R:\Morrison\joe\currencyconflict_tradepolicy\china\raw\"; 
local dodir "R:\Morrison\joe\currencyconflict_tradepolicy\china\do\";
local dtadir "R:\Morrison\joe\currencyconflict_tradepolicy\china\dta\";
local pngdir "R:\Morrison\joe\currencyconflict_tradepolicy\china\png\";
local outdir "R:\Morrison\joe\currencyconflict_tradepolicy\china\output\";
local logdir "R:\Morrison\joe\currencyconflict_tradepolicy\china\log\";

cd `dodir';
log using `logdir's3_china.txt, replace;


** --------------------------------------------------------------------------- ;
** Figure 1 - Real effective exchange rate & nominal bilateral ;
** --------------------------------------------------------------------------- ;
import excel `rawdir'figure1data_haver.xlsx, clear;

* format;
rename A date;
rename B exrate;
rename C reer;
drop if _n==1;

destring exrate, replace;
destring reer, replace;

gen time = monthly(date,"YM");
format time %tm;

order date time;
sort time;

* flip exchange rate;
gen rmb = exrate/100;

* label variables;
label variable rmb "Nominal Bilateral";
label variable reer "Real Effective Exchange Rate";

* graph;
twoway (line reer time if time>=tm(1995m1), yaxis(2) lw(medthick) lpa(dash) ylab(70(10)130, axis(2)))
   (line rmb time if time>=tm(1995m1),  yscale(reverse) yaxis(1) lw(medthick) lpa(solid) ylab(4.5(0.5)8.5, axis(1))),
   tlab(1995m1(60)2015m1) xtitle("") ytitle("CNY/USD", axis(1)) ytitle("Index, 2010=100", axis(2)) 
   legend(span) saving(`outdir'figure1,replace);
graph export `outdir'figure1.pdf, as(pdf) replace;


** --------------------------------------------------------------------------- ;
** Figure 2 - Current account imbalances ;
** --------------------------------------------------------------------------- ;
use `dtadir'chinachartdata.dta, clear;

gen cab1 = cabillions if ifs==111;
gen cab2 = cabillions if ifs==924;
gen cab3 = cabillions if ifs==158;
gen cab4 = cabillions if ifs==163;

label variable cab1 "United States";
label variable cab2 "China";
label variable cab3 "Japan";
label variable cab4 "Euro Area";

graph bar cab1-cab4 if year>=1995&year<=2018&(ifs==111|ifs==158|ifs==163|ifs==924), 
   over(year, rel(1 "1995" 2 " " 3 " " 4 " " 5 " " 6 " " 7 " " 8 " " 9 " " 10 " " 11 "2005" 
   12 " " 13 " " 14 " " 15 " " 16 " " 17 " " 18 " " 19 " " 20 " " 21 "2015" 22 " " 23 " " 24 " ")) stack ytitle("USD billions")
   text(0 13750 "- - - - - - - - - - - - - - - - - - - - - -", place(c) orient(vertical)size(vlarge)) 
   bar(1, color(black)) bar(2, color(maroon)) bar(3, color(green*0.75)) bar(4, color(sand)) 
   legend(label(1 "United States") label(2 "China") label(3 "Japan") label(4 "Euro Area")) saving(`outdir'figure2,replace);
graph export `outdir'figure2.pdf, as(pdf) replace;


** --------------------------------------------------------------------------- ;
** Figure 3 - Chinese current account balance ;
** --------------------------------------------------------------------------- ;
line cab_gdp year if ifs==924&year>=1995&year<=2017, ylab(-6(3)12) yline(-3 3, lpa(dash)) yline(0) xtitle("")
   ytitle("Percent of GDP") ttext(8 1996 "FX purchases not allowed", placement(e)) 
   ttext(7 1996 "FX sales encouraged", placement(e)) ttext(1.5 1996 "FX sales encouraged, purchases discouraged", placement(e)) 
   ttext(-1.5 1996 "FX purchases encouraged, sales discouraged", placement(e)) ttext(-5 1996 "FX sales not allowed", placement(e)) 
   ttext(-6 1996 "FX purchases encouraged", placement(e)) ttext(8 2009 "Current account balance", placement(e))
   saving(`outdir'figure3, replace);
graph export `outdir'figure3.pdf, as(pdf) replace;


** --------------------------------------------------------------------------- ;
** Figure 4 - Chinese current account balance ;
** --------------------------------------------------------------------------- ;
gen metricimp = 0.25*gsimportbillions;

label variable nosbillions "Net Official Assets";
label variable reserve_stock "Foreign Exchange Reserves";
label variable metricimp "Three Months Imports";
label variable stextdebtb1 "Short-term External Debt";

line nosbillions reserve_stock metricimp stextdebtb1 year if ifs==924&year>=1995&year<=2017,
   xtitle("") lpa(solid dash dot dash_dot) lwidth(medium medium thick medthick) ytitle("USD billions")
   lcolor(blue red green purple) saving(`outdir'figure4, replace);
graph export `outdir'figure4.pdf, as(pdf) replace;


** --------------------------------------------------------------------------- ;
** Figure 5 - Chinese investment ;
** --------------------------------------------------------------------------- ;
gen investment1 = investmentCHN;
gen investment2 = investmentEMxCHN;
gen investment3 = investmentavgKOR;
gen investment4 = investmentavgTWN;

expand 2 in 1 if ifs==1;
replace year = 2024 if _n==_N;
sort ifs year;

label variable investment1 "China";
label variable investment2 "EM excluding China";
label variable investment3 "Korea, 1980-97";
label variable investment4 "Taiwan, 1980-97";

twoway bar investment1 investment2 year if year>=1995&year<=2017&(ifs==1), color(eltblue edkblue) || 
	line investment3 investment4 year if year>=1994&year<=2018&(ifs==1), color(red sandb) lwidth(thick thick)
	yline(0, lcolor(black)) xlabel(1995(5)2018) ylabel(0(10)50) 
	xtitle("") ytitle("Percent of GDP") saving(`outdir'figure5,replace);
graph export `outdir'figure5.pdf, as(pdf) replace;

twoway bar investment1 investment2 year if year>=1995&year<=2023&(ifs==1), color(eltblue edkblue) || 
	line investment3 investment4 year if year>=1994&year<=2024&(ifs==1), color(red sandb) lwidth(thick thick) ||
	pci 0 2017.5 50 2017.5, lcolor(black) lwidth(medthick) lpattern(dash) 
	legend(order(1 2 3 4)) yline(0, lcolor(black)) xlabel(1995(5)2020) ylabel(0(10)50) 
	xtitle("") ytitle("Percent of GDP") saving(`outdir'figure5a,replace);
graph export `outdir'figure5a.pdf, as(pdf) replace;


log close;
